========
Analysis
========

The analysis module provides tools for tag similarity detection and consolidation.

Tag Similarity
===============

.. autoclass:: pinboard_tools.analysis.similarity.TagSimilarityDetector
   :members:
   :undoc-members:
   :show-inheritance:

Tag Consolidation
=================

.. autoclass:: pinboard_tools.analysis.consolidation.TagConsolidator
   :members:
   :undoc-members:
   :show-inheritance: